@@ -14,14 +14,20 @@ that contains pre-defined standard functions ``dustpy.std`` that can be used in
 from dustpy import plot
 from dustpy.simulation import Simulation
 from dustpy import constants
+from dustpy import utils
 from dustpy.utils import hdf5writer
 
 from simframe.io.dump import readdump
 from simframe.io.writers import hdf5writer
 
 __name__ = "dustpy"
-__version__ = "0.4.3"
+__version__ = "0.4.6"
 
 Simulation.__version__ = __version__
+plot.__version__ = __version__
+utils.__version__ = __version__
 
 __all__ = ["constants", "hdf5writer", "plot", "readdump", "Simulation"]
+
+# Print warning if dustpy version is outdated
+utils.print_version_warning()
