@@ -6,6 +6,8 @@ module constants
     double precision :: G = 6.674299999999999d-08
     double precision :: k_B = 1.380649d-16
     double precision :: m_p = 1.67262192369d-24
+    double precision :: M_earth = 5.972167867791379d27
+    double precision :: M_jup = 1.8981245973360504d30
     double precision :: M_sun = 1.988409870698051d33
     double precision :: pi = ACOS(-1.d0)
     double precision :: R_sun = 6.9570000000d10
