@@ -17,13 +17,14 @@ import dustpy.std.star as std_star
 
 from dustpy.utils import hdf5writer
 from dustpy.utils.boundary import Boundary
+from dustpy.utils import print_version_warning
 
 import numpy as np
 from types import SimpleNamespace
 
 
 class Simulation(Frame):
-    '''The main simulation class for running dust coagulation simulations.
+    """The main simulation class for running dust coagulation simulations.
 
     `dustpy.Simulation`` is a child of ``simframe.Frame``.
 
@@ -32,12 +33,12 @@ class Simulation(Frame):
     For initialization use ``Simulation.initialize()``,
     For running simulations use ``Simulation.run()``.
 
-    Please have a look at the documentation of ``simframe`` for further details.'''
+    Please have a look at the documentation of ``simframe`` for further details."""
 
     __name__ = "DustPy"
 
     def __init__(self, **kwargs):
-        '''Main simulation class.'''
+        """Main simulation class."""
 
         super().__init__(**kwargs)
 
